@@ -433,12 +433,18 @@ def sync(
             src='files/tempdir',
             dest='/tmp/tempdir',
         )
-    '''
 
-    # If we don't enforce the source ending with /, remote_dirpath below might start with
-    # a /, which makes the os_path.join cut off the destination bit.
-    if not src.endswith(os_path.sep):
-        src = '{0}{1}'.format(src, os_path.sep)
+    Note: ``exclude`` and ``exclude_dir`` use ``fnmatch`` behind the scenes to do the filtering.
+
+    + ``exclude`` matches against the filename.
+    + ``exclude_dir`` matches against the path of the directory, relative to ``src``.
+      Since fnmatch does not treat path separators (``/`` or ``\\``) as special characters,
+      excluding all directories matching a given name, however deep under ``src`` they are,
+      can be done for example with ``exclude_dir=["__pycache__", "*/__pycache__"]``
+
+    '''
+    original_src = src  # Keep a copy to reference in errors
+    src = os_path.normpath(src)
 
     # Add deploy directory?
     if add_deploy_dir and state.deploy_dir:
@@ -446,7 +452,7 @@ def sync(
 
     # Ensure the source directory exists
     if not os_path.isdir(src):
-        raise IOError('No such directory: {0}'.format(src))
+        raise IOError('No such directory: {0}'.format(original_src))
 
     # Ensure exclude is a list/tuple
     if exclude is not None:
@@ -461,15 +467,15 @@ def sync(
     put_files = []
     ensure_dirnames = []
     for dirpath, dirnames, filenames in walk(src, topdown=True):
-        remote_dirpath = dirpath.replace(src, '')
+        remote_dirpath = os_path.normpath(os_path.relpath(dirpath, src))
 
         # Filter excluded dirs
-        for child_dir in dirnames:
-            child_path = os_path.join(remote_dirpath, child_dir)
+        for child_dir in dirnames[:]:
+            child_path = os_path.normpath(os_path.join(remote_dirpath, child_dir))
             if exclude_dir and any(fnmatch(child_path, match) for match in exclude_dir):
                 dirnames.remove(child_dir)
 
-        if remote_dirpath:
+        if remote_dirpath and remote_dirpath != os_path.curdir:
             ensure_dirnames.append((remote_dirpath, get_path_permissions_mode(dirpath)))
 
         for filename in filenames:
@@ -479,16 +485,12 @@ def sync(
             if exclude and any(fnmatch(full_filename, match) for match in exclude):
                 continue
 
-            put_files.append((
-                # Join local as normal (unix, win)
-                full_filename,
-                # Join remote as unix like
-                unix_path_join(*[
-                    item for item in
-                    (dest, remote_dirpath, filename)
-                    if item
-                ]),
-            ))
+            remote_full_filename = unix_path_join(*[
+                item for item in
+                (dest, remote_dirpath, filename)
+                if item and item != os_path.curdir
+            ])
+            put_files.append((full_filename, remote_full_filename))
 
     # Ensure the destination directory - if the destination is a link, ensure
     # the link target is a directory.
