@@ -4,11 +4,16 @@ from __future__ import unicode_literals
 
 from unittest import TestCase
 
+from mock import patch
+
+from pyinfra.api import Config, State
 from pyinfra.api.connectors.util import (
     make_unix_command,
     split_combined_output,
 )
 
+from ..util import make_inventory
+
 
 class TestConnectorUtil(TestCase):
     def test_split_combined_output_works(self):
@@ -105,3 +110,39 @@ class TestMakeUnixCommandConnectorUtil(TestCase):
             'su pyinfra -c '  # su bit
             "'bash -c '\"'\"'cd /opt/somedir && export key=value && echo hi'\"'\"''"  # command bit
         )
+
+    def test_command_exists_su_config_only(self):
+        '''
+        This tests covers a bug that appeared when `make_unix_command` is called
+        with `su_user=False` (default) but `SU_USER` set on the config object,
+        resulting in an empty command output.
+        '''
+        state = State(make_inventory(), Config(SU_USER=True))
+        command = make_unix_command('echo Šablony', state=state)
+        assert command.get_raw_value() == "sh -c 'echo Šablony'"
+
+
+class TestMakeUnixCommandConnectorUtilWarnings(TestCase):
+    def test_sudo_warnings(self):
+        state = State(make_inventory(), Config(SU_USER=True))
+
+        with patch('pyinfra.api.connectors.util._warn_invalid_auth_args') as fake_auth_args:
+            command = make_unix_command('echo Šablony', state=state)
+
+        assert command.get_raw_value() == "sh -c 'echo Šablony'"
+        fake_auth_args.assert_called_once()
+        _, args, kwargs = fake_auth_args.mock_calls[0]
+        assert args[1] == 'sudo'
+        assert args[2] == ('use_sudo_password', 'use_sudo_login', 'preserve_sudo_env', 'sudo_user')
+
+    def test_su_warnings(self):
+        state = State(make_inventory(), Config(SUDO=True))
+
+        with patch('pyinfra.api.connectors.util._warn_invalid_auth_args') as fake_auth_args:
+            command = make_unix_command('echo Šablony', state=state)
+
+        assert command.get_raw_value() == "sh -c 'echo Šablony'"
+        fake_auth_args.assert_called_once()
+        _, args, kwargs = fake_auth_args.mock_calls[0]
+        assert args[1] == 'su_user'
+        assert args[2] == ('use_su_login', 'preserve_su_env', 'su_shell')
